@@ -29,7 +29,7 @@ use strict;
 use vars qw($VERSION);
 use Image::ExifTool qw(:DataAccess :Utils);
 
-$VERSION = '1.47';
+$VERSION = '1.49';
 
 sub ConvertTimecode($);
 sub ProcessSGLT($$$);
@@ -528,7 +528,7 @@ my %code2charset = (
         },
     },
     SLLT => { #PH (BikeBro)
-        Name => 'BikeBroLocation',
+        Name => 'BikeBroGPS',
         SubDirectory => {
             TagTable => 'Image::ExifTool::QuickTime::Stream',
             ProcessProc => \&ProcessSLLT,
@@ -1360,7 +1360,7 @@ sub CalcDuration($@)
 # Returns: 1 on success
 sub ProcessStreamData($$$)
 {
-    my ($et, $dirInfo, $tagTablePtr) = @_;
+    my ($et, $dirInfo, $tagTbl) = @_;
     my $dataPt = $$dirInfo{DataPt};
     my $start = $$dirInfo{DirStart};
     my $size = $$dirInfo{DirLen};
@@ -1369,9 +1369,9 @@ sub ProcessStreamData($$$)
         $et->VerboseDir($$dirInfo{DirName}, 0, $size);
     }
     my $tag = substr($$dataPt, $start, 4);
-    my $tagInfo = $et->GetTagInfo($tagTablePtr, $tag);
+    my $tagInfo = $et->GetTagInfo($tagTbl, $tag);
     unless ($tagInfo) {
-        $tagInfo = $et->GetTagInfo($tagTablePtr, 'unknown');
+        $tagInfo = $et->GetTagInfo($tagTbl, 'unknown');
         return 1 unless $tagInfo;
     }
     my $subdir = $$tagInfo{SubDirectory};
@@ -1398,7 +1398,7 @@ sub ProcessStreamData($$$)
         my $subTable = GetTagTable($$subdir{TagTable});
         $et->ProcessDirectory(\%subdirInfo, $subTable);
     } else {
-        $et->HandleTag($tagTablePtr, $tag, undef,
+        $et->HandleTag($tagTbl, $tag, undef,
             DataPt  => $dataPt,
             DataPos => $$dirInfo{DataPos},
             Start   => $start,
@@ -1414,12 +1414,12 @@ sub ProcessStreamData($$$)
 # Inputs: 0) Tag table ref, 1) tag ID
 sub MakeTagInfo($$)
 {
-    my ($tagTablePtr, $tag) = @_;
+    my ($tagTbl, $tag) = @_;
     my $name = $tag;
     my $n = ($name =~ s/([\x00-\x1f\x7f-\xff])/'x'.unpack('H*',$1)/eg);
     # print in hex if tag is numerical
     $name = sprintf('0x%.4x',unpack('N',$tag)) if $n > 2;
-    AddTagToTable($tagTablePtr, $tag, {
+    AddTagToTable($tagTbl, $tag, {
         Name => "Unknown_$name",
         Description => "Unknown $name",
         Unknown => 1,
@@ -1434,7 +1434,7 @@ sub MakeTagInfo($$)
 # Returns: 1 on success
 sub ProcessChunks($$$)
 {
-    my ($et, $dirInfo, $tagTablePtr) = @_;
+    my ($et, $dirInfo, $tagTbl) = @_;
     my $dataPt = $$dirInfo{DataPt};
     my $start = $$dirInfo{DirStart};
     my $size = $$dirInfo{DirLen};
@@ -1467,7 +1467,7 @@ sub ProcessChunks($$$)
             $len -= 4;
             $start += 4;
         }
-        my $tagInfo = $et->GetTagInfo($tagTablePtr, $tag);
+        my $tagInfo = $et->GetTagInfo($tagTbl, $tag);
         my $baseShift = 0;
         my $val;
         if ($tagInfo) {
@@ -1484,7 +1484,7 @@ sub ProcessChunks($$$)
                     $start -= $base;
                 }
             } elsif (not $$tagInfo{Binary}) {
-                my $format = $$tagInfo{Format} || $$tagTablePtr{FORMAT};
+                my $format = $$tagInfo{Format} || $$tagTbl{FORMAT};
                 if ($format and $format eq 'string') {
                     $val = substr($$dataPt, $start, $len);
                     $val =~ s/\0+$//;   # remove trailing nulls from strings
@@ -1493,9 +1493,9 @@ sub ProcessChunks($$$)
                 }
             }
         } elsif ($verbose or $unknown) {
-            MakeTagInfo($tagTablePtr, $tag);
+            MakeTagInfo($tagTbl, $tag);
         }
-        $et->HandleTag($tagTablePtr, $tag, $val,
+        $et->HandleTag($tagTbl, $tag, $val,
             DataPt  => $dataPt,
             DataPos => $$dirInfo{DataPos} - $baseShift,
             Start   => $start,
@@ -1515,7 +1515,7 @@ sub ProcessChunks($$$)
 # Returns: 1 on success
 sub ProcessSGLT($$$)
 {
-    my ($et, $dirInfo, $tagTablePtr) = @_;
+    my ($et, $dirInfo, $tagTbl) = @_;
     my $dataPt = $$dirInfo{DataPt};
     my $dataLen = length $$dataPt;
     my $ee = $et->Options('ExtractEmbedded');
@@ -1524,19 +1524,21 @@ sub ProcessSGLT($$$)
     # 0           1  2  3           4  5           6  7
     # 00 00 00 24 02 00 00 01 17 04 00 00 00 00 00 00 00 00 9b 02
     # frame------ ?? Xs X---------- Ys Y---------- Zs Z----------
-    SetByteOrder('MM');
+    $$et{SET_GROUP0} = $$et{SET_GROUP1} = 'RIFF';
     for ($pos=0; $pos<=$dataLen-20; $pos+=20) {
         $$et{DOC_NUM} = ++$$et{DOC_COUNT};
         my $buff = substr($$dataPt, $pos);
         my @a = unpack('NCCNCNCN', $buff);
         my @acc = ($a[3]*($a[2]?-1:1)/1e5, $a[5]*($a[4]?-1:1)/1e5, $a[7]*($a[6]?-1:1)/1e5);
-        $et->HandleTag($tagTablePtr, FrameNumber   => $a[0]);
-        $et->HandleTag($tagTablePtr, Accelerometer => "@acc");
+        $et->HandleTag($tagTbl, FrameNumber   => $a[0]);
+        $et->HandleTag($tagTbl, Accelerometer => "@acc");
         unless ($ee) {
             $et->Warn('Use ExtractEmbedded option to extract all accelerometer data', 3);
             last;
         }
     }
+    delete $$et{SET_GROUP0};
+    delete $$et{SET_GROUP1};
     $$et{DOC_NUM} = 0;
     return 0;
 }
@@ -1547,7 +1549,7 @@ sub ProcessSGLT($$$)
 # Returns: 1 on success
 sub ProcessSLLT($$$)
 {
-    my ($et, $dirInfo, $tagTablePtr) = @_;
+    my ($et, $dirInfo, $tagTbl) = @_;
     my $dataPt = $$dirInfo{DataPt};
     my $dataLen = length $$dataPt;
     my $ee = $et->Options('ExtractEmbedded');
@@ -1556,25 +1558,27 @@ sub ProcessSLLT($$$)
     # 0           1  2     3           4     5           6     7     8  9  10 11    12 13 14 15
     # 00 00 00 17 01 00 00 03 fa 21 ec 00 35 01 6e c0 06 00 08 00 62 10 0b 1b 07 e2 03 0e 57 4e
     # frame------ ?? lonDD lonDDDDDDDD latDD latDDDDDDDD alt-- spd-- hr mn sc yr--- mn dy EW NS
-    SetByteOrder('MM');
+    $$et{SET_GROUP0} = $$et{SET_GROUP1} = 'RIFF';
     for ($pos=0; $pos<=$dataLen-30; $pos+=30) {
         $$et{DOC_NUM} = ++$$et{DOC_COUNT};
         my $buff = substr($$dataPt, $pos);
         my @a = unpack('NCnNnNnnCCCnCCaa', $buff);
         # - is $a[1] perhaps GPSStatus? (only seen 1, or perhaps record type 1=GPS, 2=acc?)
         my $time = sprintf('%.4d:%.2d:%.2d %.2d:%.2d:%.2dZ', @a[11..13, 8..10]);
-        $et->HandleTag($tagTablePtr, FrameNumber  => $a[0]);
-        $et->HandleTag($tagTablePtr, GPSDateTime  => $time);
-        $et->HandleTag($tagTablePtr, GPSLatitude  => ($a[4] + $a[5]/1e8) * ($a[15] eq 'S' ? -1 : 1));
-        $et->HandleTag($tagTablePtr, GPSLongitude => ($a[2] + $a[3]/1e8) * ($a[14] eq 'W' ? -1 : 1));
-        $et->HandleTag($tagTablePtr, GPSSpeed     => $a[7]);
-        $et->HandleTag($tagTablePtr, GPSSpeedRef  => 'K');
-        $et->HandleTag($tagTablePtr, GPSAltitude  => $a[6]);
+        $et->HandleTag($tagTbl, FrameNumber  => $a[0]);
+        $et->HandleTag($tagTbl, GPSDateTime  => $time);
+        $et->HandleTag($tagTbl, GPSLatitude  => ($a[4] + $a[5]/1e8) * ($a[15] eq 'S' ? -1 : 1));
+        $et->HandleTag($tagTbl, GPSLongitude => ($a[2] + $a[3]/1e8) * ($a[14] eq 'W' ? -1 : 1));
+        $et->HandleTag($tagTbl, GPSAltitude  => $a[6]);
+        $et->HandleTag($tagTbl, GPSSpeed     => $a[7]);
+        $et->HandleTag($tagTbl, GPSSpeedRef  => 'K');
         unless ($ee) {
             $et->Warn('Use ExtractEmbedded option to extract timed GPS', 3);
             last;
         }
     }
+    delete $$et{SET_GROUP0};
+    delete $$et{SET_GROUP1};
     $$et{DOC_NUM} = 0;
     return 1;
 }
@@ -1603,12 +1607,13 @@ sub ProcessRIFF($$)
         $buff .= $buf2;
         return 0 unless $buff =~ /WAVE(.{4})?fmt /sg and $raf->Seek(pos($buff) - 4, 0);
     }
+    $$raf{NoBuffer} = 1 if $et->Options('FastScan'); # disable buffering in FastScan mode
     $mime = $riffMimeType{$type} if $type;
     $et->SetFileType($type, $mime);
     $$et{VALUE}{FileType} .= ' (RF64)' if $rf64;
     $$et{RIFFStreamType} = '';    # initialize stream type
     SetByteOrder('II');
-    my $tagTablePtr = GetTagTable('Image::ExifTool::RIFF::Main');
+    my $tagTbl = GetTagTable('Image::ExifTool::RIFF::Main');
     my $pos = 12;
 #
 # Read chunks in RIFF image
@@ -1653,10 +1658,10 @@ sub ProcessRIFF($$)
         }
         # RIFF chunks are padded to an even number of bytes
         my $len2 = $len + ($len & 0x01);
-        if ($$tagTablePtr{$tag} or (($verbose or $unknown) and $tag !~ /^(data|idx1|LIST_movi|RIFF)$/)) {
+        if ($$tagTbl{$tag} or (($verbose or $unknown) and $tag !~ /^(data|idx1|LIST_movi|RIFF)$/)) {
             $raf->Read($buff, $len2) == $len2 or $err=1, last;
-            MakeTagInfo($tagTablePtr, $tag) if not $$tagTablePtr{$tag} and ($verbose or $unknown);
-            $et->HandleTag($tagTablePtr, $tag, $buff,
+            MakeTagInfo($tagTbl, $tag) if not $$tagTbl{$tag} and ($verbose or $unknown);
+            $et->HandleTag($tagTbl, $tag, $buff,
                 DataPt  => \$buff,
                 DataPos => 0,   # (relative to Base)
                 Start   => 0,
